/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    context.h
 * @author  Leerang Song (leerang.song@samsung.com)
 */


#ifndef WEBAPP_DETAIL_CONTEXT_H
#define WEBAPP_DETAIL_CONTEXT_H

#include <string>
#include <vector>
#include <Elementary.h>
#include <dpl/fast_delegate.h>
#include <wrt-commons/security-origin-dao/security_origin_dao.h>

namespace WebAppDetailSetting {
//Update Callback
typedef DPL::FastDelegate0<void> OriginViewUpdate;
typedef DPL::FastDelegate0<void> PermissionViewUpdate;
struct Callback {
OriginViewUpdate originViewUpdate;
PermissionViewUpdate permissionViewUpdate;
};

class Context {
  public:
    Evas_Object* parent;
    SecurityOriginDB::SecurityOriginDAOPtr dao;
    std::vector<std::string> originData;
    std::string selectedOrigin;
    std::vector<SecurityOriginDB::SecurityOriginDataPtr> permissionData;

    Callback cbs;

    Context();
    virtual ~Context();
    void setOriginData(void);
    void setPermissionData(void);
    void setSelectedOrigin(unsigned int index);
    void removePermissionData(unsigned int index);
    void removeAllPermissionData(void);
    bool getPermissionResult(unsigned int index);
};
} // namespace WebAppDetailSetting

#endif // WEBAPP_DETAIL_CONTEXT_H
