/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    ctxpopup_view.cpp
 * @author  Leerang Song (leerang.song@samsung.com)
 */

#include "ctxpopup_view.h"

#include <string>
#include <Elementary.h>
#include <efl_assist.h>
#include <dpl/assert.h>
#include <dpl/foreach.h>

#include "util.h"

namespace WebAppDetailSetting {
namespace {
} // anonymous namespace

CtxpopupView::CtxpopupView() :
    m_parent(NULL),
    m_ctxpopup(NULL),
    m_isShowed(false)
{
}

CtxpopupView::~CtxpopupView(void)
{
}

void CtxpopupView::init(Evas_Object* parent, CtxpopupItemDataList list)
{
    Assert(parent);
    m_parent = parent;

    if (list.empty()) {
        _E("menu data is empty");
        Assert(false);
    }
    m_ctxpopupItemDataList = list;

    // create ctxpopup
    m_ctxpopup = elm_ctxpopup_add(m_parent);
    elm_object_style_set(m_ctxpopup, "more/default");

    ea_object_event_callback_add(m_ctxpopup,
                                 EA_CALLBACK_BACK,
                                 ea_ctxpopup_back_cb,
                                 NULL);
    ea_object_event_callback_add(m_ctxpopup,
                                 EA_CALLBACK_MORE,
                                 ea_ctxpopup_back_cb,
                                 NULL);
    evas_object_smart_callback_add(m_ctxpopup,
                                   "dismissed",
                                   dismissedCallback,
                                   this);
    evas_object_event_callback_add(m_parent,
                                   EVAS_CALLBACK_RESIZE,
                                   rotationChangedCallback,
                                   this);

    // item append
    FOREACH(it, m_ctxpopupItemDataList) {
        Evas_Object* icon = NULL;
        if (!it->iconPath.empty()) {
            // create icon
        }
        elm_ctxpopup_item_append(m_ctxpopup,
                                 it->text.c_str(),
                                 icon,
                                 itemCallback,
                                 this);
    }

    // move ctxpopup position to left of bottom
    Evas_Object* top = elm_object_top_widget_get(m_parent);
    Evas_Coord h;
    evas_object_geometry_get(top, NULL, NULL, NULL, &h);
    evas_object_move(m_ctxpopup, 0, h);
}

void CtxpopupView::deinit(void)
{
    Assert(m_ctxpopup);
    m_ctxpopupItemDataList.clear();
    evas_object_smart_callback_del(m_ctxpopup,
                                   "dismissed",
                                   dismissedCallback);
    Evas_Object* top = elm_object_top_widget_get(m_parent);
    evas_object_event_callback_del(top,
                                   EVAS_CALLBACK_RESIZE,
                                   rotationChangedCallback);
    evas_object_del(m_ctxpopup);
    m_ctxpopup = NULL;
}

void CtxpopupView::show(void)
{
    Assert(m_ctxpopup);
    evas_object_show(m_ctxpopup);
}

void CtxpopupView::hide(void)
{
    Assert(m_ctxpopup);
    evas_object_hide(m_ctxpopup);
}

bool CtxpopupView::isShowed(void)
{
    return m_isShowed;
}


void CtxpopupView::itemCallback(void* data, Evas_Object* obj, void* eventInfo)
{
    UNUSED_PARAM(obj);

    Assert(data);
    CtxpopupView* This = static_cast<CtxpopupView*>(data);

    Assert(eventInfo);
    Elm_Object_Item* it = static_cast<Elm_Object_Item*>(eventInfo);
    const char* text = elm_object_item_text_get(it);

    FOREACH(it, This->m_ctxpopupItemDataList) {
        if (it->text == text) {
            it->function();
            break;
        }
    }
    This->hide();
}

void CtxpopupView::dismissedCallback(void* data,
                                     Evas_Object* obj,
                                     void* eventInfo)
{
    UNUSED_PARAM(obj);
    UNUSED_PARAM(eventInfo);

    Assert(data);
    CtxpopupView* This = static_cast<CtxpopupView*>(data);
    This->hide();
}

void CtxpopupView::rotationChangedCallback(void *data, Evas *e, Evas_Object *obj, void *event_info)
{
    UNUSED_PARAM(e);
    UNUSED_PARAM(obj);
    UNUSED_PARAM(event_info);

    Assert(data);
    CtxpopupView* This = static_cast<CtxpopupView*>(data);

    Evas_Object* top = elm_object_top_widget_get(This->m_ctxpopup);
	Evas_Coord h;
    evas_object_geometry_get(top, NULL, NULL, NULL,  &h);
    evas_object_move(This->m_ctxpopup, 0, h);
}
} // namespace WebAppDetailSetting
