/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    ctxpopup_view.h
 * @author  Leerang Song (leerang.song@samsung.com)
 */


#ifndef WEBAPP_DETAIL_CTXPOPUP_VIEW_H_
#define WEBAPP_DETAIL_CTXPOPUP_VIEW_H_

#include <memory>
#include <string>
#include <list>
#include <Elementary.h>
#include <dpl/fast_delegate.h>

namespace WebAppDetailSetting {

class CtxpopupView
{
  public:
    typedef DPL::FastDelegate0<void> CtxpopupCallbackType;
    struct CtxpopupItemData {
        std::string text;
        std::string iconPath;
        CtxpopupCallbackType function;
        CtxpopupItemData(std::string t,
                         std::string p,
                         CtxpopupCallbackType f) :
            text(t),
            iconPath(p),
            function(f)
        {}
    };
    typedef std::list<CtxpopupItemData> CtxpopupItemDataList;

    CtxpopupView();
    virtual ~CtxpopupView(void);
    void init(Evas_Object* parent, CtxpopupItemDataList list);
    void deinit(void);
    void show(void);
    void hide(void);
    bool isShowed(void);

  private:
    // ctxpopup callback
    static void itemCallback(void* data,
                             Evas_Object* obj,
                             void* eventInfo);
    static void dismissedCallback(void* data,
                                          Evas_Object* obj,
                                          void* eventInfo);
    static void rotationChangedCallback(void *data, Evas *e, Evas_Object *obj, void *event_info);

    Evas_Object* m_parent;
    Evas_Object* m_ctxpopup;
    CtxpopupItemDataList m_ctxpopupItemDataList;
    bool m_isShowed;
};
} // namespace WebAppDetailSetting

#endif // WEBAPP_DETAIL_CTXPOPUP_VIEW_H_
