/*
  * Copyright 2012  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */

#include <memory>

#include <ui-gadget.h>
#include <ui-gadget-module.h>
#include <Elementary.h>
#include <app_service.h>

#include <dpl/assert.h>

#include "util.h"
#include "main_view.h"

#define EXPORT_SYMBOL extern "C" __attribute__((visibility("default")))

struct priv {
    std::unique_ptr<WebAppDetailSetting::MainView> mainView;
};

namespace {
const char* const KEY_PKGNAME = "pkg_name";
} // anonymous namespace

static void* onCreate(ui_gadget_h ug,
                      enum ug_mode mode,
                      service_h service,
                      void* data)
{
    _D("called");
    UNUSED_PARAM(mode);

    Assert(ug && data);
    struct priv* Priv = static_cast<struct priv *>(data);

    // get package name
    char* pkgname = NULL;
    service_get_extra_data(service, KEY_PKGNAME, &pkgname);
    if (!pkgname) {
        _E("passed package name is invalid");
        return NULL;
    }
    _D("Passed packname : %s", pkgname);

    Priv->mainView.reset(new WebAppDetailSetting::MainView(ug));
    Priv->mainView->init(pkgname);

    return Priv->mainView->getLayout();
}

static void onDestroy(ui_gadget_h /*ug*/,
                      service_h /*service*/,
                      void *user_data)
{
    _D("called");
    Assert(user_data);
    struct priv* Priv = static_cast<struct priv *>(user_data);
    Priv->mainView.reset();
}

EXPORT_SYMBOL int UG_MODULE_INIT(struct ug_module_ops* ops)
{
    _D("called");
    Assert(ops);
    struct priv* Priv = new priv;
    if (!Priv) {
        _E("Fail to alloc priv");
        return -1;
    }
    Priv->mainView.reset();

    memset(ops, 0x00, sizeof(*ops));
    ops->priv = Priv;
    ops->create = onCreate;
    ops->destroy = onDestroy;
    ops->opt = UG_OPT_INDICATOR_ENABLE;

    return 0;
}

EXPORT_SYMBOL void UG_MODULE_EXIT(struct ug_module_ops* ops)
{
    _D("called");
    Assert(ops);
    struct priv* Priv = static_cast<struct priv*>(ops->priv);
    if (!Priv) {
        return;
    } else {
        Priv->mainView.reset();
        delete Priv;
    }
}
