/*
  * Copyright 2013  Samsung Electronics Co., Ltd
  *
  * Licensed under the Flora License, Version 1.1 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
  *     http://floralicense.org/license/
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
/**
 * @file    wrt_setting_text.cpp
 * @author  Leerang Song (leerang.song@samsung.com)
 */

#include "wrt_setting_text.h"

#include <dpl/wrt-dao-ro/widget_dao_types.h>

#include "util.h"

namespace WrtSettingText {
char* getFeatureText(const WrtDB::Feature index)
{
    switch (index) {
        case WrtDB::FEATURE_GEOLOCATION:
            return strdup(WRT_SETTING_OPT_ACCESS_USER_LOCATION);
        case WrtDB::FEATURE_WEB_NOTIFICATION:
            return strdup(WRT_SETTING_HEADER_WEB_NOTIFICATION);
        case WrtDB::FEATURE_USER_MEDIA:
            return strdup(WRT_SETTING_OPT_USE_USER_MEDIA);
        case WrtDB::FEATURE_FULLSCREEN_MODE:
            return strdup(WRT_SETTING_BODY_FULL_SCREEN);
        case WrtDB::FEATURE_WEB_DATABASE:
            return strdup(WRT_SETTING_OPT_USE_STORE_WEB_DATA);
    }
    _E("out of index : %d", index);
    return strdup("Unknown");
}

char* getDescriptionText(const WrtDB::Feature index)
{
    switch (index) {
        case WrtDB::FEATURE_GEOLOCATION:
            return strdup(WRT_SETTING_BODY_ALLOWS_THIS_SITE_TO_ACCESS_YOUR_LOCATION_INFORMATION);
        case WrtDB::FEATURE_WEB_NOTIFICATION:
            return strdup(WRT_SETTING_BODY_ALLOWS_THIS_SITE_TO_DISPLAY_NOTIFICATIONS);
        case WrtDB::FEATURE_USER_MEDIA:
            return strdup(WRT_SETTING_BODY_ALLOWS_THIS_SITE_TO_USE_THE_MEDIA_FILES_STORED_ON_YOUR_DEVICE);
        case WrtDB::FEATURE_FULLSCREEN_MODE:
            return strdup(WRT_SETTING_BODY_ALLOWS_THIS_SITE_TO_CHANGE_THE_DISPLAY_TO_FULL_SCREEN);
        case WrtDB::FEATURE_WEB_DATABASE:
            return strdup(WRT_SETTING_BODY_ALLOWS_THIS_SITE_TO_SAVE_A_LARGE_AMOUNT_OF_DATA_ON_YOUR_DEVICE);
    }
    _E("out of index : %d", index);
    return strdup("Unknown");
}
} // namespace WrtSettingText

